@@ -1963,7 +1963,7 @@ static CCSBackendVTable tdeconfigVTable =
 extern "C"
 {
 
-    CCSBackendVTable *
+    KDE_EXPORT CCSBackendVTable *
     getBackendInfo (void)
     {
 	return &tdeconfigVTable;
